@@ -83,7 +83,7 @@ class Runner(Authenticate):
 
     def get_kwargs(self):
         # todo can we handle files automatically.
-        self.params.update(self.inputs.get('query_parameters'))
+        self.params.update(self.inputs.get('parameters', {}))
         return {
             'params': self.params,
             'data': self.inputs.get('data_body'),
